==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/photos/l10n/sk.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Verejný odkaz",
    "Photos" : "Fotografie",
    "Your memories under your control" : "Vaše spomienky pod vašou kontrolou",
    "All media" : "Všetky médiá",
    "Videos" : "Videá",
    "Albums" : "Albumy",
    "Collaborative albums" : "Kolaboratívne albumy",
    "People" : "Ľudia",
    "Folders" : "Priečinky",
    "Favorites" : "Obľúbené",
    "On this day" : "V tento deň",
    "Shared with you" : "Vám sprístupnené",
    "Tags" : "Štítky",
    "Locations" : "Umiestnenie",
    "Photos settings" : "Nastavenia fotiek",
    "Mark selection as favorite" : "Označiť vybrané ako obľúbené",
    "Add selection to favorites" : "Pridať vybrané ako obľúbené",
    "Remove selection from favorites" : "Odstrániť vybrané z obľúbených",
    "Name of the album" : "Pomenovať album",
    "Location of the album" : "Umiestnenie albumu",
    "Go back to the previous view." : "Vrátiť sa na predchádzajúce zobrazenie.",
    "Back" : "Späť",
    "Go to the add collaborators view." : "Ísť na zobrazenie pre pridanie spolupracujúcich.",
    "Add collaborators" : "Pridať spolupracujúcich",
    "Save." : "Uložiť.",
    "Create the album." : "Vytvoriť album.",
    "Save" : "Uložiť",
    "Create album" : "Vytvoriť album",
    "Back to the new album form." : "Späť na formulár pre pridanie nového albumu.",
    "Add to Album" : "Pridať do Albumu",
    "Create a new album." : "Vytvoriť nový album.",
    "Create new album" : "Vytvoriť nový album",
    "New album" : "Nový album",
    "_%n item_::_%n photos and videos_" : ["%n fotka alebo video","%n fotky a videá","%n fotiek a videí","%n fotiek a videí"],
    "_Share with %n user_::_Share with %n users_" : ["Zdieľať s %n užívateľom","Zdieľať s %n užívateľmi","Zdieľať s %n užívateľmi","Zdieľať s %n užívateľmi"],
    "Add people or groups who can edit your album" : "Pridať užívateľov alebo skupiny ktoré môžu upravovať váš album",
    "Search for collaborators" : "Vyhľadať spolupracovníkov",
    "Search people or groups" : "Vyhľadať užívateľov alebo skupiny",
    "Add {collaboratorLabel} to the collaborators list" : "Pridať {collaboratorLabel} na zoznam spolupracovníkov",
    "No collaborators available" : "Nie sú dostupný žiadny spolupracovníci",
    "Remove {collaboratorLabel} from the collaborators list" : "Odobrať {collaboratorLabel} zo zoznamu spolupracovníkov",
    "Copy the public link" : "Kopírovať verejný odkaz",
    "Public link copied!" : "Verejný odkaz skopírovaný!",
    "Copy public link" : "Kopírovať verejný odkaz",
    "Delete the public link" : "Zmazať verejný odkaz",
    "Share via public link" : "Zdieľať ako verejný odkaz",
    "Failed to fetch collaborators list." : "Nepodarilo sa získať zoznam spolupracovníkov.",
    "Failed to fetch album." : "Nepodarilo sa načítať album.",
    "Failed to update album." : "Nepodarilo sa aktualizovať album.",
    "This collection does not exist" : "Kolekcia neexistuje",
    "An error occurred" : "Vyskytla sa chyba",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "Select image {imageName}" : "Vybrať obrázok {imageName}",
    "The file is in the favorites" : "Súbor je medzi obľúbenými",
    "Open the full size \"{name}\" image" : "Otvoriť fotografiu „{name}“ v pôvodnej veľkosti",
    "There are no photos or videos yet!" : "Zatiaľ tu nie sú žiadne fotky alebo videá!",
    "Add to {destination}" : "Pridať do {destination}",
    "Open the \"{name}\" sub-directory" : "Otvoriť podpriečinok „{name}“",
    "Back to {folder}" : "Späť do {folder}",
    "Share this folder" : "Sprístupniť tento priečinok",
    "_{years} year ago_::_{years} years ago_" : ["{years} rok spať","{years} roky späť","{years} rokov späť","{years} rokov späť"],
    "Enable squared photos view" : "Zapnúť štvorcové zobrazenie fotiek",
    "Default Photos upload and Albums location" : "Východzie umiestnenie pre nahrávanie Fotiek a Albumov",
    "Select the default location for your media" : "Vyberte východzie umiestnenie pre vaše médiá",
    "Invalid location selected" : "Bolo vybrané neplatné umiestnenie",
    "View" : "Prezerať",
    "Photos directory" : "Priečinok pre fotky",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "Manage collaborators for this album" : "Spravovať spolupracovníkov pre tento album",
    "Open actions menu" : "Otvoriť ponuku akcií",
    "Edit album details" : "Upraviť podrobnosti o albume",
    "Download all files in album" : "Stiahnuť všetky súbory z albumu",
    "Delete album" : "Zmazať album",
    "Download selected files" : "Stiahnuť vybrané súbory",
    "Remove selection from album" : "Odstrániť vybrané z albumu",
    "This album does not have any photos or videos yet!" : "Tento album zatiaľ neobsahuje žiadne fotky alebo videá!",
    "Add photos to this album" : "Pridať fotky do tohto albumu",
    "Add photos to the album" : "Pridať fotky do albumu",
    "Manage collaborators" : "Spravovať spolupracovníkov",
    "Save collaborators for this album." : "Uložiť spolupracovníkov pre tento album.",
    "Cover photo for album {albumName}" : "Fotka obalu pre album {albumName}",
    "There is no album yet!" : "Zatiaľ tu nie je žiadny album!",
    "This person could not be found" : "Túto osobu sa nepodarilo nájisť",
    "Rename person" : "Premenovať osobu",
    "Merge with different person" : "Spojiť s inou osobou",
    "Download selected photos" : "Stiahnuť vybrané fotky",
    "Favorite" : "Obľúbené",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Remove person" : "Odstrániť osobu",
    "Name of this person" : "Meno tejto osoby",
    "Merge person" : "Spojiť osobu",
    "_Remove photo from person_::_Remove photos from person_" : ["Odstrániť fotky z osoby","Odstrániť fotky z osôb","Odstrániť fotky z osôb","Odstrániť fotky z osôb"],
    "This might take some time depending on the size of your photo library." : "Toto môže chvíľu trvať podľa veľkosti vašej knižnice fotiek.",
    "Recognized people will show up here" : "Rozpoznané osoby sa zobrazia tu",
    "This folder does not exist" : "Tento priečinok neexistuje",
    "Loading folders …" : "Nahrať priečinky ...",
    "No photos in here" : "Nie sú tu žiadne fotografie",
    "Failed to fetch albums list." : "Nepodarilo sa načítať zoznam albumov.",
    "Shared albums" : "Zdieľané albumy",
    "Cover photo for shared album {albumName}." : "Fotka obalu pre zdieľaný album {albumName}.",
    "Back to tags overview" : "Späť k prehladu štítkov",
    "No photos with this tag yet" : "Zatiaľ nie sú žiadne fotky s týmto štítkom",
    "No tags yet" : "Zatiaľ žiadne štítky",
    "Photos with tags will show up here" : "Fotografie so štítkami sa zobrazia tu",
    "Popular tags" : "Populárne štítky",
    "Add" : "Pridať",
    "Create a new album" : "Vytvoriť nový album",
    "Add selection to an album" : "Pridať vybrané do albumu",
    "Add to album" : "Pridať do albumu",
    "Delete selection" : "Zmazanie výberu",
    "Failed to fetch faces list." : "Nepodarilo sa načítať zoznam tvárí.",
    "All your media" : "Všetky vaše médiá",
    "Tagged photos" : "Označené fotografie",
    "Failed to create {albumName}." : "Zlyhalo vytváranie {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Chyba pri premenovávaní {currentAlbumName} na {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "Chyba pri premenovávaní {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nepodarilo sa zmazať {faceName}.",
    "Failed to delete {fileId}." : "Nepodarilo sa zmazať {fileId}.",
    "Failed to delete {fileName}." : "Nepodarilo sa zmazať {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nepodarilo sa nastaviť obľúbený stav pre {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nepodarilo sa nastaviť obľúbený stav pre {fileName}.",
    "Your photos" : "Vaše fotografie",
    "Your videos" : "Vaše videá",
    "Your folders" : "Vaše priečinky",
    "Settings" : "Nastavenia"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-28.0.5.tar.bz2: nextcloud/apps/photos/l10n/sk.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Verejný odkaz",
    "Photos" : "Fotografie",
    "On This Day" : "V tento deň",
    "Your memories under your control" : "Vaše spomienky pod vašou kontrolou",
    "All media" : "Všetky médiá",
    "Videos" : "Videá",
    "Albums" : "Albumy",
    "Collaborative albums" : "Kolaboratívne albumy",
    "People" : "Ľudia",
    "Folders" : "Priečinky",
    "Favorites" : "Obľúbené",
    "On this day" : "V tento deň",
    "Shared with you" : "Vám sprístupnené",
    "Tags" : "Štítky",
    "Places" : "Miesta",
    "Map" : "Mapa",
    "Photos settings" : "Nastavenia fotiek",
    "Mark selection as favorite" : "Označiť vybrané ako obľúbené",
    "Add selection to favorites" : "Pridať vybrané ako obľúbené",
    "Remove selection from favorites" : "Odstrániť vybrané z obľúbených",
    "Name of the album" : "Pomenovať album",
    "Location of the album" : "Umiestnenie albumu",
    "Back" : "Späť",
    "Add collaborators" : "Pridať spolupracujúcich",
    "Save" : "Uložiť",
    "Create album" : "Vytvoriť album",
    "Add to Album" : "Pridať do Albumu",
    "Add selection to album {albumName}" : "Pridať vybrané do albumu {ablumName}",
    "Shared by" : "Zdieľané od",
    "Create a new album." : "Vytvoriť nový album.",
    "Create new album" : "Vytvoriť nový album",
    "New album" : "Nový album",
    "_%n item_::_%n photos and videos_" : ["%n fotka alebo video","%n fotky a videá","%n fotiek a videí","%n fotiek a videí"],
    "Add people or groups who can edit your album" : "Pridať užívateľov alebo skupiny ktoré môžu upravovať váš album",
    "Search people or groups" : "Vyhľadať užívateľov alebo skupiny",
    "No recommendations. Start typing." : "Žiadne odporúčania. Môžete začať písať.",
    "Group" : "Skupina",
    "Remove {collaboratorLabel} from the collaborators list" : "Odobrať {collaboratorLabel} zo zoznamu spolupracovníkov",
    "Copy the public link" : "Kopírovať verejný odkaz",
    "Public link copied!" : "Verejný odkaz skopírovaný!",
    "Copy public link" : "Kopírovať verejný odkaz",
    "Delete the public link" : "Zmazať verejný odkaz",
    "Create public link share" : "Vytvoriť verejný odkaz so zdieľaním",
    "Share via public link" : "Zdieľať ako verejný odkaz",
    "Failed to fetch collaborators list." : "Nepodarilo sa získať zoznam spolupracovníkov.",
    "Failed to update album." : "Nepodarilo sa aktualizovať album.",
    "This collection does not exist" : "Kolekcia neexistuje",
    "An error occurred" : "Vyskytla sa chyba",
    "No picture for this day" : "Žiadny obrázok pre tento deň",
    "Picture taken on this day will show up here." : "Tu sa zobrazí fotografia urobená v tento deň.",
    "More photos from this day" : "Viac fotiek z tohto dňa",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nepriradená fotografia","%n nepriradené fotografie","%n nepriradených fotografií","%n nepriradených fotografií"],
    "Favorite" : "Obľúbené",
    "Select image {imageName}" : "Vybrať obrázok {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Obľúbený obrázok, otvoriť plnú veľkosť obrázka \"{name}\"",
    "Open the full size \"{name}\" image" : "Otvoriť fotografiu „{name}“ v pôvodnej veľkosti",
    "Open the \"{name}\" folder" : "Otvoriť adresár \"{name}\"",
    "Go back" : "Ísť späť",
    "Back to {folder}" : "Späť do {folder}",
    "Share this folder" : "Sprístupniť tento priečinok",
    "Dates" : "Dátumy",
    "Jump to specific date in list" : "Preskočiť na konkrétny dátum v zozname",
    "Jump to {date}" : "Preskočiť na {date}",
    "Add to {destination}" : "Pridať do {destination}",
    "There are no photos or videos yet!" : "Zatiaľ tu nie sú žiadne fotky alebo videá!",
    "_{years} year ago_::_{years} years ago_" : ["{years} rok spať","{years} roky späť","{years} rokov späť","{years} rokov späť"],
    "Enable squared photos view" : "Zapnúť štvorcové zobrazenie fotiek",
    "Delete source directory" : "Vymazať zdrojový adresár",
    "All folders" : "Všetky adresáre",
    "Select a source folder for your media" : "Vyberte zdrojový adresár pre vaše médiá.",
    "Home" : "Domov",
    "Choose default Photos upload and Albums location" : "Vyberte predvolené umiestnenie pre nahrávané Fotky a Albumy",
    "Choose a different folder" : "Vyberať iný adresár",
    "Select the default upload location for your media" : "Vyberte východzie umiestnenie pre vaše médiá.",
    "View" : "Prezerať",
    "Choose the folders from where photos and videos are shown." : "Vyberte adresáre, z ktorých sa zobrazujú fotografie a videá.",
    "Upload folder" : "Nahrať adresár",
    "Choose the folder where photos and albums are uploaded to." : "Vyberať adresár, do ktorého sa nahrávajú fotografie a albumy.",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "Unselect all" : "Zrušiť výber",
    "Manage collaborators for this album" : "Spravovať spolupracovníkov pre tento album",
    "Open actions menu" : "Otvoriť ponuku akcií",
    "Edit album details" : "Upraviť podrobnosti o albume",
    "Download all files in album" : "Stiahnuť všetky súbory z albumu",
    "Delete album" : "Zmazať album",
    "Download selected files" : "Stiahnuť vybrané súbory",
    "Remove selection from album" : "Odstrániť vybrané z albumu",
    "This album does not have any photos or videos yet!" : "Tento album zatiaľ neobsahuje žiadne fotky alebo videá!",
    "Add photos to this album" : "Pridať fotky do tohto albumu",
    "Add photos to {albumName}" : "Pridať fotky do {albumName}",
    "Manage collaborators" : "Spravovať spolupracovníkov",
    "Save collaborators for this album." : "Uložiť spolupracovníkov pre tento album.",
    "Cover photo for album {albumName}" : "Fotka obalu pre album {albumName}",
    "There is no album yet!" : "Zatiaľ tu nie je žiadny album!",
    "This person could not be found" : "Túto osobu sa nepodarilo nájisť",
    "Rename person" : "Premenovať osobu",
    "Merge with different person" : "Spojiť s inou osobou",
    "Download selected photos" : "Stiahnuť vybrané fotky",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Remove person" : "Odstrániť osobu",
    "Name of this person" : "Meno tejto osoby",
    "Save." : "Uložiť.",
    "Merge person" : "Spojiť osobu",
    "Move to different person" : "Prepnúť sa na inú osobu",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Presunúť fotografiu na inú osobu.","Presunúť fotografie na inú osobu","Presunúť fotografie na inú osobu","Presunúť fotografie na inú osobu"],
    "_Remove photo from person_::_Remove photos from person_" : ["Odstrániť fotky z osoby","Odstrániť fotky z osôb","Odstrániť fotky z osôb","Odstrániť fotky z osôb"],
    "This might take some time depending on the size of your photo library." : "Toto môže chvíľu trvať podľa veľkosti vašej knižnice fotiek.",
    "Recognized people will show up here" : "Rozpoznané osoby sa zobrazia tu",
    "This folder does not exist" : "Tento priečinok neexistuje",
    "Loading folders …" : "Nahrať priečinky ...",
    "No photos in here" : "Nie sú tu žiadne fotografie",
    "Taken on {date} at {time}" : "Vytvorené dňa {date} o {time}",
    "This place does not have any photos or videos yet!" : "Tento miesto zatiaľ neobsahuje žiadne fotky alebo videá!",
    "Add photos to this place" : "Pridať fotky do tohto miesta",
    "Cover photo for place {placeName}" : "Fotka obalu pre miesto {placeName}",
    "There is no place yet!" : "Zatiaľ tu nie je žiadne miesto!",
    "Cover photo for shared album {albumName}." : "Fotka obalu pre zdieľaný album {albumName}.",
    "Back to tags overview" : "Späť k prehladu štítkov",
    "No photos with this tag yet" : "Zatiaľ nie sú žiadne fotky s týmto štítkom",
    "No tags yet" : "Zatiaľ žiadne štítky",
    "Photos with tags will show up here" : "Fotografie so štítkami sa zobrazia tu",
    "Popular tags" : "Populárne štítky",
    "Add" : "Pridať",
    "Add to album" : "Pridať do albumu",
    "Delete selection" : "Zmazanie výberu",
    "No photos or videos in here" : "Nie sú tu žiadne obrázky ani videá",
    "Unassigned faces" : "Nepridané tváre",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotiek","%n fotiek"],
    "Failed to fetch collection." : "Zlyhalo načítanie kolekcie.",
    "Failed to fetch collections list." : "Zlyhalo načítanie zoznamu kolekcií.",
    "Failed to fetch faces list." : "Nepodarilo sa načítať zoznam tvárí.",
    "All your media" : "Všetky vaše médiá",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Zdieľané albumy",
    "Shared album {title}" : "Sprístupnený album {title}",
    "Public album {title}" : "Verejný album {title}",
    "Tagged photos" : "Označené fotografie",
    "Tagged photo {title}" : "Oštítkovaná fotografia {title}",
    "{title}'s face" : "tvár {title}",
    "{startDate} to {endDate}" : "{startDate} do {endDate}",
    "Details" : "Podrobnosti",
    "Failed to rename {oldName} to {faceName}." : "Chyba pri premenovávaní {oldName} na {faceName}.",
    "Failed to delete {faceName}." : "Nepodarilo sa zmazať {faceName}.",
    "Failed to delete {fileId}." : "Nepodarilo sa zmazať {fileId}.",
    "Failed to delete {fileName}." : "Nepodarilo sa zmazať {fileName}.",
    "Failed to set favorite state for {fileId}." : "Nepodarilo sa nastaviť obľúbený stav pre {fileId}.",
    "Failed to set favorite state for {fileName}." : "Nepodarilo sa nastaviť obľúbený stav pre {fileName}.",
    "Could not load photos folder" : "Nepodarilo sa načítať adresár s fotkami",
    "Go back to the previous view." : "Vrátiť sa na predchádzajúce zobrazenie.",
    "Go to the add collaborators view." : "Ísť na zobrazenie pre pridanie spolupracujúcich.",
    "Create the album." : "Vytvoriť album.",
    "Back to the new album form." : "Späť na formulár pre pridanie nového albumu.",
    "_Share with %n user_::_Share with %n users_" : ["Zdieľať s %n užívateľom","Zdieľať s %n užívateľmi","Zdieľať s %n užívateľmi","Zdieľať s %n užívateľmi"],
    "Search for collaborators" : "Vyhľadať spolupracovníkov",
    "Add {collaboratorLabel} to the collaborators list" : "Pridať {collaboratorLabel} na zoznam spolupracovníkov",
    "No collaborators available" : "Nie sú dostupný žiadny spolupracovníci",
    "Failed to fetch album." : "Nepodarilo sa načítať album.",
    "The file is in the favorites" : "Súbor je medzi obľúbenými",
    "Open the \"{name}\" sub-directory" : "Otvoriť podpriečinok „{name}“",
    "Default Photos upload and Albums location" : "Predvolené umiestnenie pre nahrávané Fotky a Albumy",
    "Select the default location for your media" : "Vyberte východzie umiestnenie pre vaše médiá",
    "Invalid location selected" : "Bolo vybrané neplatné umiestnenie",
    "Photos directory" : "Priečinok pre fotky",
    "Add photos to the album" : "Pridať fotky do albumu",
    "Failed to fetch albums list." : "Nepodarilo sa načítať zoznam albumov.",
    "Shared albums" : "Zdieľané albumy",
    "Create a new album" : "Vytvoriť nový album",
    "Add selection to an album" : "Pridať vybrané do albumu",
    "Failed to create {albumName}." : "Zlyhalo vytváranie {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Chyba pri premenovávaní {currentAlbumName} na {newAlbumName}.",
    "Choose a Photos source for the timelines" : "Vyberte zdroj fotografií pre časové osi",
    "Media folder" : "Adresár medií",
    "The source folder does not exists" : "Zdrojový adresár neexistuje"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
